You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [4/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ mai...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/AuthorizationException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/AuthorizationException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/AuthorizationException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/AuthorizationException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/AuthorizationException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/AuthorizationException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/AuthorizationException.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization;
+package org.apache.wicket.authorization;
 
-import wicket.WicketRuntimeException;
+import org.apache.wicket.WicketRuntimeException;
 
 /**
  * Base class for exceptions thrown as a result of authorization failure.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IAuthorizationStrategy.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IAuthorizationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IAuthorizationStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IAuthorizationStrategy.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IAuthorizationStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IAuthorizationStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IAuthorizationStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization;
+package org.apache.wicket.authorization;
 
-import wicket.Component;
-import wicket.settings.ISecuritySettings;
+import org.apache.wicket.Component;
+import org.apache.wicket.settings.ISecuritySettings;
 
 /**
  * Authorization strategies specify aspect-like constraints on significant
@@ -39,7 +39,7 @@
 	public static final IAuthorizationStrategy ALLOW_ALL = new IAuthorizationStrategy()
 	{
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 		 */
 		public boolean isInstantiationAuthorized(final Class c)
 		{
@@ -47,8 +47,8 @@
 		}
 
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-		 *      wicket.authorization.Action)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+		 *      org.apache.wicket.authorization.Action)
 		 */
 		public boolean isActionAuthorized(Component c, Action action)
 		{
@@ -66,7 +66,7 @@
 	 * <p>
 	 * If you wish to implement a strategy that authenticates users which cannot
 	 * access a given Page (or other Component), you can simply throw a
-	 * {@link wicket.RestartResponseAtInterceptPageException} in your
+	 * {@link org.apache.wicket.RestartResponseAtInterceptPageException} in your
 	 * implementation of this method.
 	 * 
 	 * @param componentClass

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IUnauthorizedComponentInstantiationListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IUnauthorizedComponentInstantiationListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IUnauthorizedComponentInstantiationListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IUnauthorizedComponentInstantiationListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IUnauthorizedComponentInstantiationListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/IUnauthorizedComponentInstantiationListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/IUnauthorizedComponentInstantiationListener.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization;
+package org.apache.wicket.authorization;
 
-import wicket.Component;
+import org.apache.wicket.Component;
 
 /**
  * Interface to code that is called to handle unauthorized component
@@ -33,7 +33,7 @@
 	 * @param component
 	 *            The partially constructed component (only the id is guaranteed
 	 *            to be valid).
-	 * @see wicket.application.IComponentInstantiationListener
+	 * @see org.apache.wicket.application.IComponentInstantiationListener
 	 */
 	void onUnauthorizedInstantiation(Component component);
 }

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedActionException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedActionException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedActionException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedActionException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedActionException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedActionException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedActionException.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization;
+package org.apache.wicket.authorization;
 
-import wicket.Component;
+import org.apache.wicket.Component;
 
 /**
  * Exception that is thrown when an action is not authorized.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedInstantiationException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedInstantiationException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedInstantiationException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedInstantiationException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedInstantiationException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/UnauthorizedInstantiationException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/UnauthorizedInstantiationException.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization;
+package org.apache.wicket.authorization;
 
 /**
  * Exception that is thrown when the creation of a component is not allowed.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/CompoundAuthorizationStrategy.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/CompoundAuthorizationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/CompoundAuthorizationStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/CompoundAuthorizationStrategy.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/CompoundAuthorizationStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/CompoundAuthorizationStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/CompoundAuthorizationStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization.strategies;
+package org.apache.wicket.authorization.strategies;
 
 import java.util.ArrayList;
 
-import wicket.Component;
-import wicket.authorization.Action;
-import wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.Component;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
+
 
 /**
  * Compound implementation of the IAuthorizationStrategy that lets you chain two
@@ -49,7 +50,7 @@
 	}
 
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 	 */
 	public final boolean isInstantiationAuthorized(Class componentClass)
 	{
@@ -66,8 +67,8 @@
 	}
 
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-	 *      wicket.authorization.Action)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+	 *      org.apache.wicket.authorization.Action)
 	 */
 	public final boolean isActionAuthorized(Component component, Action action)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/ActionAuthorizationStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization.strategies.action;
+package org.apache.wicket.authorization.strategies.action;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import wicket.Component;
-import wicket.authorization.Action;
-import wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.Component;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
+
 
 /**
  * An authorization strategy which allows the use of a command pattern for users
@@ -48,7 +49,7 @@
 	}
 
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 	 */
 	public boolean isInstantiationAuthorized(Class componentClass)
 	{
@@ -56,8 +57,8 @@
 	}
 
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-	 *      wicket.authorization.Action)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+	 *      org.apache.wicket.authorization.Action)
 	 */
 	public boolean isActionAuthorized(Component component, Action action)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/IActionAuthorizer.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/IActionAuthorizer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/IActionAuthorizer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/IActionAuthorizer.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/IActionAuthorizer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/action/IActionAuthorizer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/action/IActionAuthorizer.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization.strategies.action;
+package org.apache.wicket.authorization.strategies.action;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.authorization.Action;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.authorization.Action;
 
 /**
  * A way to provide authorization for a specific component action.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/AbstractPageAuthorizationStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization.strategies.page;
+package org.apache.wicket.authorization.strategies.page;
 
-import wicket.Component;
-import wicket.Page;
-import wicket.authorization.Action;
-import wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.Component;
+import org.apache.wicket.Page;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
 
 /**
  * An abstract base class for implementing simple authorization of Pages. Users
@@ -32,8 +32,8 @@
 public abstract class AbstractPageAuthorizationStrategy implements IAuthorizationStrategy
 {
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-	 *      wicket.authorization.Action)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+	 *      org.apache.wicket.authorization.Action)
 	 */
 	public boolean isActionAuthorized(final Component component, final Action action)
 	{
@@ -41,7 +41,7 @@
 	}
 
 	/**
-	 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+	 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 	 */
 	public final boolean isInstantiationAuthorized(final Class/* <Component> */componentClass)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/authorization/strategies/page/SimplePageAuthorizationStrategy.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.authorization.strategies.page;
+package org.apache.wicket.authorization.strategies.page;
 
-import wicket.Application;
-import wicket.Component;
-import wicket.Page;
-import wicket.RestartResponseAtInterceptPageException;
-import wicket.authorization.IUnauthorizedComponentInstantiationListener;
-import wicket.authorization.UnauthorizedInstantiationException;
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.Page;
+import org.apache.wicket.RestartResponseAtInterceptPageException;
+import org.apache.wicket.authorization.IUnauthorizedComponentInstantiationListener;
+import org.apache.wicket.authorization.UnauthorizedInstantiationException;
 
 /**
  * A very simple authorization strategy that takes a supertype (a base class or
@@ -103,7 +103,7 @@
 	}
 
 	/**
-	 * @see wicket.authorization.strategies.page.AbstractPageAuthorizationStrategy#isPageAuthorized(java.lang.Class)
+	 * @see org.apache.wicket.authorization.strategies.page.AbstractPageAuthorizationStrategy#isPageAuthorized(java.lang.Class)
 	 */
 	protected boolean isPageAuthorized(final Class pageClass)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractAjaxBehavior.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractAjaxBehavior.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractAjaxBehavior.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractAjaxBehavior.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractAjaxBehavior.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractAjaxBehavior.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractAjaxBehavior.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.RequestListenerInterface;
-import wicket.Response;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.IHeaderResponse;
-import wicket.protocol.http.request.WebRequestCodingStrategy;
-import wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.Component;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.Response;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.IHeaderResponse;
+import org.apache.wicket.protocol.http.request.WebRequestCodingStrategy;
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
 /**
  * Abstract class for handling Ajax roundtrips. This class serves as a base for
@@ -129,8 +129,8 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#onComponentTag(wicket.Component,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.behavior.IBehavior#onComponentTag(org.apache.wicket.Component,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	public final void onComponentTag(final Component component, final ComponentTag tag)
 	{
@@ -138,7 +138,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractBehavior#onRendered(wicket.Component)
+	 * @see org.apache.wicket.behavior.AbstractBehavior#onRendered(org.apache.wicket.Component)
 	 */
 	public final void onRendered(final Component hostComponent)
 	{
@@ -146,7 +146,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.IHeaderContributor#renderHead(IHeaderResponse)
+	 * @see org.apache.wicket.markup.html.IHeaderContributor#renderHead(IHeaderResponse)
 	 */
 	public void renderHead(final IHeaderResponse response)
 	{
@@ -192,7 +192,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractBehavior#getStatelessHint(Component)
+	 * @see org.apache.wicket.behavior.AbstractBehavior#getStatelessHint(Component)
 	 */
 	public boolean getStatelessHint(Component component)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractBehavior.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractBehavior.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractBehavior.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractBehavior.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.IHeaderResponse;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.IHeaderResponse;
 
 /**
- * Adapter implementation of {@link wicket.behavior.IBehavior}. It is
+ * Adapter implementation of {@link org.apache.wicket.behavior.IBehavior}. It is
  * recommended to extend from this class instead of directly implementing
- * {@link wicket.behavior.IBehavior} as this class has an extra clean
+ * {@link org.apache.wicket.behavior.IBehavior} as this class has an extra clean
  * 
  * @author Ralf Ebert
  * @author Eelco Hillenius
@@ -39,14 +39,14 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#beforeRender(wicket.Component)
+	 * @see org.apache.wicket.behavior.IBehavior#beforeRender(org.apache.wicket.Component)
 	 */
 	public void beforeRender(Component component)
 	{
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#bind(wicket.Component)
+	 * @see org.apache.wicket.behavior.IBehavior#bind(org.apache.wicket.Component)
 	 */
 	public void bind(final Component component)
 	{
@@ -63,7 +63,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#detachModel(Component)
+	 * @see org.apache.wicket.behavior.IBehavior#detachModel(Component)
 	 */
 	public void detachModel(Component component)
 	{
@@ -71,7 +71,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#exception(wicket.Component,
+	 * @see org.apache.wicket.behavior.IBehavior#exception(org.apache.wicket.Component,
 	 *      java.lang.RuntimeException)
 	 */
 	public final void exception(Component component, RuntimeException exception)
@@ -87,7 +87,7 @@
 	}
 	
 	/**
-	 * @see wicket.behavior.IBehavior#getStatelessHint(wicket.Component)
+	 * @see org.apache.wicket.behavior.IBehavior#getStatelessHint(org.apache.wicket.Component)
 	 */
 	public boolean getStatelessHint(Component component)
 	{
@@ -95,8 +95,8 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#onComponentTag(wicket.Component,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.behavior.IBehavior#onComponentTag(org.apache.wicket.Component,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	public void onComponentTag(final Component component, final ComponentTag tag)
 	{
@@ -128,7 +128,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#rendered(wicket.Component)
+	 * @see org.apache.wicket.behavior.IBehavior#rendered(org.apache.wicket.Component)
 	 */
 	public final void rendered(final Component component)
 	{
@@ -143,14 +143,14 @@
 	}
 	
 	/**
-	 * @see wicket.markup.html.IHeaderContributor#renderHead(wicket.markup.html.IHeaderResponse)
+	 * @see org.apache.wicket.markup.html.IHeaderContributor#renderHead(org.apache.wicket.markup.html.IHeaderResponse)
 	 */
 	public void renderHead(IHeaderResponse response)
 	{
 	}
 	
 	/**
-	 * @see wicket.behavior.IBehavior#isEnabled(Component)
+	 * @see org.apache.wicket.behavior.IBehavior#isEnabled(Component)
 	 */
 	public boolean isEnabled(Component component)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractHeaderContributor.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractHeaderContributor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractHeaderContributor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractHeaderContributor.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractHeaderContributor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AbstractHeaderContributor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AbstractHeaderContributor.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.IHeaderResponse;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.IHeaderResponse;
 
 /**
  * Behaviour that delegates header contribution to a number of other
@@ -45,7 +45,7 @@
 	public abstract IHeaderContributor[] getHeaderContributors();
 
 	/**
-	 * @see wicket.markup.html.IHeaderContributor#renderHead(wicket.Response)
+	 * @see org.apache.wicket.markup.html.IHeaderContributor#renderHead(org.apache.wicket.Response)
 	 */
 	public final void renderHead(final IHeaderResponse response)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AttributeAppender.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AttributeAppender.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AttributeAppender.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AttributeAppender.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AttributeAppender.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/AttributeAppender.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/AttributeAppender.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.AttributeModifier;
-import wicket.model.IModel;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
+import org.apache.wicket.AttributeModifier;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
 
 /**
  * AttributeModifier that appends the given value, rather than replace it. This
@@ -97,7 +97,7 @@
 	}
 
 	/**
-	 * @see wicket.AttributeModifier#newValue(java.lang.String,
+	 * @see org.apache.wicket.AttributeModifier#newValue(java.lang.String,
 	 *      java.lang.String)
 	 */
 	protected String newValue(String currentValue, String appendValue)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/HeaderContributor.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/HeaderContributor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/HeaderContributor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/HeaderContributor.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/HeaderContributor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehavior.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.markup.ComponentTag;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.markup.ComponentTag;
 
 /**
  * Behaviors are kind of plug-ins for Components. They allow to be added to a
@@ -30,14 +30,14 @@
  * component.
  * <p>
  * It is recommended that you extend from
- * {@link wicket.behavior.AbstractBehavior} instead of directly implementing
+ * {@link org.apache.wicket.behavior.AbstractBehavior} instead of directly implementing
  * this interface.
  * </p>
  * 
- * @see wicket.behavior.IBehaviorListener
- * @see wicket.markup.html.IHeaderContributor
- * @see wicket.behavior.AbstractAjaxBehavior
- * @see wicket.AttributeModifier
+ * @see org.apache.wicket.behavior.IBehaviorListener
+ * @see org.apache.wicket.markup.html.IHeaderContributor
+ * @see org.apache.wicket.behavior.AbstractAjaxBehavior
+ * @see org.apache.wicket.AttributeModifier
  * 
  * @author Ralf Ebert
  * @author Eelco Hillenius

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehaviorListener.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehaviorListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehaviorListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehaviorListener.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehaviorListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehaviorListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehaviorListener.java Tue Apr 10 11:15:14 2007
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.IRequestListener;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.RequestListenerInterface;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.BehaviorRequestTarget;
+import org.apache.wicket.Component;
+import org.apache.wicket.IRequestListener;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.BehaviorRequestTarget;
 
 /**
- * Listens for requests to behaviors. When {@link wicket.behavior.IBehavior}s
+ * Listens for requests to behaviors. When {@link org.apache.wicket.behavior.IBehavior}s
  * are 'enriched' with this interface, they can receive requests themselves. You
  * can use this for example to implement AJAX behavior, though you'll probably
- * want to extend from {@link wicket.behavior.AbstractAjaxBehavior} directly
+ * want to extend from {@link org.apache.wicket.behavior.AbstractAjaxBehavior} directly
  * instead in that case.
  * 
  * @author Eelco Hillenius

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IUnversionedBehaviorListener.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IUnversionedBehaviorListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IUnversionedBehaviorListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IUnversionedBehaviorListener.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IUnversionedBehaviorListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IUnversionedBehaviorListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IUnversionedBehaviorListener.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.IRequestTarget;
-import wicket.Page;
-import wicket.RequestListenerInterface;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.BehaviorRequestTarget;
+import org.apache.wicket.Component;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestListenerInterface;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.BehaviorRequestTarget;
 
 /**
- * Same as {@link wicket.behavior.IBehaviorListener}, but urls generated for
+ * Same as {@link org.apache.wicket.behavior.IBehaviorListener}, but urls generated for
  * this interface will always be executed against the latest page version.
  * 
  * @author Igor Vaynberg

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/SimpleAttributeModifier.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/SimpleAttributeModifier.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/SimpleAttributeModifier.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/SimpleAttributeModifier.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/SimpleAttributeModifier.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/SimpleAttributeModifier.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/SimpleAttributeModifier.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.markup.ComponentTag;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.ComponentTag;
 
 /**
  * A lightweight version of the attribute modifier. This is convenient for
@@ -59,8 +59,8 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractBehavior#onComponentTag(wicket.Component,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.behavior.AbstractBehavior#onComponentTag(org.apache.wicket.Component,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	public void onComponentTag(final Component component, final ComponentTag tag)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/StringHeaderContributor.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/StringHeaderContributor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/StringHeaderContributor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/StringHeaderContributor.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/StringHeaderContributor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/StringHeaderContributor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/StringHeaderContributor.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Component;
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.IHeaderResponse;
-import wicket.model.IModel;
-import wicket.model.Model;
-import wicket.util.lang.Objects;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.IHeaderResponse;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.util.lang.Objects;
 
 /**
  * A simple header contributor that just spits out the string it is constructed
@@ -83,7 +83,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.IHeaderContributor#renderHead(wicket.Response)
+		 * @see org.apache.wicket.markup.html.IHeaderContributor#renderHead(org.apache.wicket.Response)
 		 */
 		public void renderHead(IHeaderResponse response)
 		{
@@ -149,7 +149,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractHeaderContributor#getHeaderContributors()
+	 * @see org.apache.wicket.behavior.AbstractHeaderContributor#getHeaderContributors()
 	 */
 	public final IHeaderContributor[] getHeaderContributors()
 	{
@@ -157,7 +157,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractBehavior#detachModel(wicket.Component)
+	 * @see org.apache.wicket.behavior.AbstractBehavior#detachModel(org.apache.wicket.Component)
 	 */
 	public void detachModel(Component component)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ComponentFeedbackMessageFilter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ComponentFeedbackMessageFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ComponentFeedbackMessageFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ComponentFeedbackMessageFilter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ComponentFeedbackMessageFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ComponentFeedbackMessageFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ComponentFeedbackMessageFilter.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
-import wicket.Component;
+import org.apache.wicket.Component;
 
 /**
  * Filter for accepting feedback messages for a particular component.
@@ -42,7 +42,7 @@
 	}
 
 	/**
-	 * @see wicket.feedback.IFeedbackMessageFilter#accept(wicket.feedback.FeedbackMessage)
+	 * @see org.apache.wicket.feedback.IFeedbackMessageFilter#accept(org.apache.wicket.feedback.FeedbackMessage)
 	 */
 	public boolean accept(FeedbackMessage message)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ContainerFeedbackMessageFilter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ContainerFeedbackMessageFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ContainerFeedbackMessageFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ContainerFeedbackMessageFilter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ContainerFeedbackMessageFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ContainerFeedbackMessageFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ContainerFeedbackMessageFilter.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
-import wicket.MarkupContainer;
+import org.apache.wicket.MarkupContainer;
 
 /**
  * Filter for child-of relationship
@@ -46,7 +46,7 @@
 	}
 
 	/**
-	 * @see wicket.feedback.IFeedbackMessageFilter#accept(wicket.feedback.FeedbackMessage)
+	 * @see org.apache.wicket.feedback.IFeedbackMessageFilter#accept(org.apache.wicket.feedback.FeedbackMessage)
 	 */
 	public boolean accept(FeedbackMessage message)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ErrorLevelFeedbackMessageFilter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ErrorLevelFeedbackMessageFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ErrorLevelFeedbackMessageFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ErrorLevelFeedbackMessageFilter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ErrorLevelFeedbackMessageFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/ErrorLevelFeedbackMessageFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/ErrorLevelFeedbackMessageFilter.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
 /**
  * Filter for accepting feedback messages of a certain error level.
@@ -40,7 +40,7 @@
 	}
 
 	/**
-	 * @see wicket.feedback.IFeedbackMessageFilter#accept(wicket.feedback.FeedbackMessage)
+	 * @see org.apache.wicket.feedback.IFeedbackMessageFilter#accept(org.apache.wicket.feedback.FeedbackMessage)
 	 */
 	public boolean accept(FeedbackMessage message)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessage.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
 import java.io.Serializable;
 
-import wicket.Component;
-import wicket.IClusterable;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+
 
 /**
  * Represents a generic message meant for the end-user/ pages.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessages.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessages.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessages.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessages.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessages.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessages.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessages.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -24,12 +24,12 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.Page;
+import org.apache.wicket.util.concurrent.CopyOnWriteArrayList;
+import org.apache.wicket.util.string.StringList;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.Page;
-import wicket.util.concurrent.CopyOnWriteArrayList;
-import wicket.util.string.StringList;
 
 /**
  * Holds list of feedback messages. The list can be added to, cleared, queried
@@ -46,7 +46,7 @@
 	private static final long serialVersionUID = 1L;
 
 	/**
-	 * Holds a list of {@link wicket.feedback.FeedbackMessage}s.
+	 * Holds a list of {@link org.apache.wicket.feedback.FeedbackMessage}s.
 	 */
 	private List messages = null;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessagesModel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessagesModel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessagesModel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessagesModel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessagesModel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/FeedbackMessagesModel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/FeedbackMessagesModel.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
 import java.io.Serializable;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 
-import wicket.Component;
-import wicket.Page;
-import wicket.Session;
-import wicket.model.IModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.Page;
+import org.apache.wicket.Session;
+import org.apache.wicket.model.IModel;
+
 
 /**
  * Model for extracting feedback messages.
@@ -98,7 +99,7 @@
 	}
 
 	/**
-	 * @see wicket.model.IModel#getObject()
+	 * @see org.apache.wicket.model.IModel#getObject()
 	 */
 	public final Object getObject()
 	{
@@ -162,7 +163,7 @@
 
 	/**
 	 * 
-	 * @see wicket.model.IModel#setObject(java.lang.Object)
+	 * @see org.apache.wicket.model.IModel#setObject(java.lang.Object)
 	 */
 	public void setObject(Object object)
 	{
@@ -170,7 +171,7 @@
 
 	/**
 	 * 
-	 * @see wicket.model.IDetachable#detach()
+	 * @see org.apache.wicket.model.IDetachable#detach()
 	 */
 	public void detach()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedback.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedback.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedback.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedback.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedback.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedback.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedback.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
 /**
  * Interface for components that present some kind of feedback to the user,

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedbackMessageFilter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedbackMessageFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedbackMessageFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedbackMessageFilter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedbackMessageFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/feedback/IFeedbackMessageFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/feedback/IFeedbackMessageFilter.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.feedback;
+package org.apache.wicket.feedback;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * Interface for filtering feedback messages

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ComponentTag.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ComponentTag.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ComponentTag.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ComponentTag.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ComponentTag.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ComponentTag.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ComponentTag.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -24,15 +24,16 @@
 import java.util.List;
 import java.util.Map;
 
-import wicket.Response;
-import wicket.behavior.IBehavior;
-import wicket.markup.parser.XmlTag;
-import wicket.markup.parser.XmlTag.Type;
-import wicket.markup.parser.filter.HtmlHandler;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.StringValue;
-import wicket.util.string.Strings;
-import wicket.util.value.IValueMap;
+import org.apache.wicket.Response;
+import org.apache.wicket.behavior.IBehavior;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.markup.parser.XmlTag.Type;
+import org.apache.wicket.markup.parser.filter.HtmlHandler;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.StringValue;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.value.IValueMap;
+
 
 /**
  * A subclass of MarkupElement which represents a "significant" markup tag, such
@@ -48,7 +49,7 @@
 	/**
 	 * Standard component id attribute always available for components
 	 * regardless of user ApplicationSettings for id attribute; value ==
-	 * 'wicket'.
+	 * 'org.apache.wicket'.
 	 */
 	public static final String DEFAULT_WICKET_NAMESPACE = "wicket";
 
@@ -200,7 +201,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getAttributes()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getAttributes()
 	 * @return The tag#s attributes
 	 */
 	public final IValueMap getAttributes()
@@ -229,7 +230,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getName()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getName()
 	 * @return The tag's name
 	 */
 	public final String getName()
@@ -238,7 +239,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getNameChanged()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getNameChanged()
 	 * @return Returns true if the name of this component tag was changed
 	 */
 	public final boolean getNameChanged()
@@ -247,7 +248,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getNamespace()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getNamespace()
 	 * @return The tag's namespace
 	 */
 	public final String getNamespace()
@@ -266,7 +267,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getPos()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getPos()
 	 * @return Tag location (index in input string)
 	 */
 	public final int getPos()
@@ -275,7 +276,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#getString(String)
+	 * @see org.apache.wicket.markup.parser.XmlTag#getString(String)
 	 * @param key
 	 *            The key
 	 * @return The string value
@@ -289,7 +290,7 @@
 	 * THIS METHOD IS NOT PART OF THE WICKET PUBLIC API. DO NOT CALL IT.
 	 * <p>
 	 * 
-	 * @see wicket.markup.parser.XmlTag#getType()
+	 * @see org.apache.wicket.markup.parser.XmlTag#getType()
 	 * @return the tag type (OPEN, CLOSE or OPEN_CLOSE).
 	 */
 	public final Type getType()
@@ -308,7 +309,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#isClose()
+	 * @see org.apache.wicket.markup.parser.XmlTag#isClose()
 	 * @return True if this tag is a close tag
 	 */
 	public final boolean isClose()
@@ -317,7 +318,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#isOpen()
+	 * @see org.apache.wicket.markup.parser.XmlTag#isOpen()
 	 * @return True if this tag is an open tag
 	 */
 	public final boolean isOpen()
@@ -329,7 +330,7 @@
 	 * @param id
 	 *            Required component id
 	 * @return True if this tag is an open tag with the given component name
-	 * @see wicket.markup.parser.XmlTag#isOpen()
+	 * @see org.apache.wicket.markup.parser.XmlTag#isOpen()
 	 */
 	public final boolean isOpen(String id)
 	{
@@ -337,7 +338,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#isOpenClose()
+	 * @see org.apache.wicket.markup.parser.XmlTag#isOpenClose()
 	 * @return True if this tag is an open and a close tag
 	 */
 	public final boolean isOpenClose()
@@ -349,7 +350,7 @@
 	 * @param id
 	 *            Required component id
 	 * @return True if this tag is an openclose tag with the given component id
-	 * @see wicket.markup.parser.XmlTag#isOpenClose()
+	 * @see org.apache.wicket.markup.parser.XmlTag#isOpenClose()
 	 */
 	public final boolean isOpenClose(String id)
 	{
@@ -407,7 +408,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#put(String, boolean)
+	 * @see org.apache.wicket.markup.parser.XmlTag#put(String, boolean)
 	 * @param key
 	 *            The key
 	 * @param value
@@ -419,7 +420,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#put(String, int)
+	 * @see org.apache.wicket.markup.parser.XmlTag#put(String, int)
 	 * @param key
 	 *            The key
 	 * @param value
@@ -431,7 +432,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#put(String, String)
+	 * @see org.apache.wicket.markup.parser.XmlTag#put(String, String)
 	 * @param key
 	 *            The key
 	 * @param value
@@ -443,7 +444,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#put(String, StringValue)
+	 * @see org.apache.wicket.markup.parser.XmlTag#put(String, StringValue)
 	 * @param key
 	 *            The key
 	 * @param value
@@ -455,7 +456,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#putAll(Map)
+	 * @see org.apache.wicket.markup.parser.XmlTag#putAll(Map)
 	 * @param map
 	 *            a key/value map
 	 */
@@ -465,7 +466,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#remove(String)
+	 * @see org.apache.wicket.markup.parser.XmlTag#remove(String)
 	 * @param key
 	 *            The key to remove
 	 */
@@ -504,7 +505,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#setName(String)
+	 * @see org.apache.wicket.markup.parser.XmlTag#setName(String)
 	 * @param name
 	 *            New tag name
 	 */
@@ -514,7 +515,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.parser.XmlTag#setNamespace(String)
+	 * @see org.apache.wicket.markup.parser.XmlTag#setNamespace(String)
 	 * @param namespace
 	 *            New tag name namespace
 	 */
@@ -565,7 +566,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.MarkupElement#toCharSequence()
+	 * @see org.apache.wicket.markup.MarkupElement#toCharSequence()
 	 */
 	public CharSequence toCharSequence()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ContainerInfo.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ContainerInfo.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ContainerInfo.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ContainerInfo.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ContainerInfo.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/ContainerInfo.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/ContainerInfo.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.Locale;
 
-import wicket.MarkupContainer;
+import org.apache.wicket.MarkupContainer;
+
 
 /**
  * Because a Component has reference to its parents, which eventually is the

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupCacheKeyProvider.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupCacheKeyProvider.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupCacheKeyProvider.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupCacheKeyProvider.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupCacheKeyProvider.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupCacheKeyProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupCacheKeyProvider.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.Locale;
 
-import wicket.MarkupContainer;
-import wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+
 
 /**
  * Wicket default implementation for the cache key used to reference the cached

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupResourceStreamProvider.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupResourceStreamProvider.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupResourceStreamProvider.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupResourceStreamProvider.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupResourceStreamProvider.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/DefaultMarkupResourceStreamProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/DefaultMarkupResourceStreamProvider.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.Locale;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.locator.IResourceStreamLocator;
 
-import wicket.Application;
-import wicket.MarkupContainer;
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.locator.IResourceStreamLocator;
 
 /**
  * Wicket default implementation for loading the markup resource stream
@@ -55,8 +55,8 @@
 	 * a markup resource should be extended for ALL components of your
 	 * application.
 	 * 
-	 * @see wicket.util.resource.locator.IResourceStreamFactory
-	 * @see wicket.markup.DefaultMarkupResourceStreamProvider
+	 * @see org.apache.wicket.util.resource.locator.IResourceStreamFactory
+	 * @see org.apache.wicket.markup.DefaultMarkupResourceStreamProvider
 	 * 
 	 * @param container
 	 * @param containerClass

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkup.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 /**
  * Holds markup as a resource (the stream that the markup came from) and a list
@@ -22,7 +22,7 @@
  * 
  * @see MarkupElement
  * @see ComponentTag
- * @see wicket.markup.RawMarkup
+ * @see org.apache.wicket.markup.RawMarkup
  * 
  * @author Jonathan Locke
  * @author Juergen Donnerstag
@@ -45,7 +45,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @param index
@@ -71,9 +71,9 @@
 	MarkupResourceStream getResource();
 
 	/**
-	 * Get the wicket namespace valid for this specific markup
+	 * Get the org.apache.wicket namespace valid for this specific markup
 	 * 
-	 * @return wicket namespace
+	 * @return org.apache.wicket namespace
 	 */
 	String getWicketNamespace();
 
@@ -86,7 +86,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @return Number of markup elements

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupCacheKeyProvider.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupCacheKeyProvider.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupCacheKeyProvider.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupCacheKeyProvider.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupCacheKeyProvider.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupCacheKeyProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupCacheKeyProvider.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.MarkupContainer;
+import org.apache.wicket.MarkupContainer;
 
 /**
  * To be implemented by MarkupContainers that wish to implement their own

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupParserFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupParserFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupParserFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupParserFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupParserFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupParserFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupParserFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 /**
  * Factory used to generate MarkupParser objects

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupResourceStreamProvider.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupResourceStreamProvider.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupResourceStreamProvider.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupResourceStreamProvider.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupResourceStreamProvider.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IMarkupResourceStreamProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IMarkupResourceStreamProvider.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.MarkupContainer;
-import wicket.util.resource.IResourceStream;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.util.resource.IResourceStream;
 
 /**
  * To be implemented by MarkupContainer which whish to implement there own

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IScopedComponent.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IScopedComponent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IScopedComponent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IScopedComponent.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IScopedComponent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/HeaderContributor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/HeaderContributor.java Tue Apr 10 11:15:14 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.behavior;
+package org.apache.wicket.behavior;
 
-import wicket.Application;
-import wicket.RequestCycle;
-import wicket.ResourceReference;
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.IHeaderResponse;
-import wicket.markup.html.resources.CompressedResourceReference;
-import wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.Application;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.ResourceReference;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.IHeaderResponse;
+import org.apache.wicket.markup.html.resources.CompressedResourceReference;
+import org.apache.wicket.protocol.http.WebRequestCycle;
 
 /**
  * A {@link wicket.behavior.AbstractHeaderContributor} behavior that is
  * specialized on package resources. If you use this class, you have to
  * pre-register the resources you want to contribute. A shortcut for common
  * cases is to call {@link #forCss(Class, String)} to contribute a package css
@@ -307,7 +307,7 @@
 	}
 
 	/**
-	 * @see wicket.behavior.AbstractHeaderContributor#getHeaderContributors()
+	 * @see org.apache.wicket.behavior.AbstractHeaderContributor#getHeaderContributors()
 	 */
 	public final IHeaderContributor[] getHeaderContributors()
 	{
@@ -14,18 +14,18 @@
 
 /**
- * A {@link wicket.behavior.AbstractHeaderContributor} behavior that is
+ * A {@link org.apache.wicket.behavior.AbstractHeaderContributor} behavior that is
  * specialized on package resources. If you use this class, you have to
  * pre-register the resources you want to contribute. A shortcut for common

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehavior.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/behavior/IBehavior.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/behavior/IBehavior.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/IScopedComponent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/IScopedComponent.java Tue Apr 10 11:15:14 2007
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 /**
  * To be implemented by Components which walks up the component tree until a
  * Page or Panel and tries to find a component with a matching wicket id if the
  * component itself does not contain it.
  * <p>
  * Note: MarkupContainer.isTransparent() in combination with ParentResolver
  * tries to resolve the wicket id with the parent only and shall be used to
  * implement transparent containers.
  * 
  * @see wicket.markup.resolver.ScopedComponentResolver
  * @see wicket.MarkupContainer#isTransparentResolver()
  * @see wicket.markup.resolver.ParentResolver
  * 
  * @author Christian Essl
  * @author Juergen Donnerstag
@@ -14,20 +14,20 @@
 /**
  * To be implemented by Components which walks up the component tree until a
- * Page or Panel and tries to find a component with a matching wicket id if the
+ * Page or Panel and tries to find a component with a matching org.apache.wicket id if the
  * component itself does not contain it.
  * <p>
@@ -14,20 +14,20 @@
  * <p>
  * Note: MarkupContainer.isTransparent() in combination with ParentResolver
- * tries to resolve the wicket id with the parent only and shall be used to
+ * tries to resolve the org.apache.wicket id with the parent only and shall be used to
  * implement transparent containers.
  * 
@@ -14,20 +14,20 @@
  * implement transparent containers.
  * 
- * @see wicket.markup.resolver.ScopedComponentResolver
- * @see wicket.MarkupContainer#isTransparentResolver()
- * @see wicket.markup.resolver.ParentResolver
+ * @see org.apache.wicket.markup.resolver.ScopedComponentResolver
+ * @see org.apache.wicket.MarkupContainer#isTransparentResolver()
+ * @see org.apache.wicket.markup.resolver.ParentResolver
  * 
  * @author Christian Essl

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/Markup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/Markup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/Markup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/Markup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/Markup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/Markup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/Markup.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.HashMap;
 import java.util.Iterator;
@@ -31,7 +31,7 @@
  * 
  * @see MarkupElement
  * @see ComponentTag
- * @see wicket.markup.RawMarkup
+ * @see org.apache.wicket.markup.RawMarkup
  * 
  * @author Jonathan Locke
  * @author Juergen Donnerstag
@@ -55,7 +55,7 @@
 	/** The encoding as found in <?xml ... encoding="" ?>. Null, else */
 	private String encoding;
 
-	/** Wicket namespace: <html xmlns:wicket="http://wicket.sourceforge.net"> */
+	/** Wicket namespace: <html xmlns:org.apache.wicket="http://org.apache.wicket.sourceforge.net"> */
 	private String wicketNamespace;
 
 	/** == wicketNamespace + ":id" */
@@ -142,7 +142,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
 	 * protected. However to allow wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @param index
@@ -166,7 +166,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
 	 * protected. However to allow wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @return Number of markup elements
@@ -199,9 +199,9 @@
 	}
 
 	/**
 	 * Get the wicket namespace valid for this specific markup
 	 * 
-	 * @return wicket namespace
+	 * @return org.apache.wicket namespace
 	 */
 	public String getWicketNamespace()
 	{
@@ -404,7 +404,7 @@
 		}
 		else if (tag.isClose() && (this.currentPath != null))
 		{
 			// For example <wicket:message> does not have an id
 			if ((tag.getOpenTag() == null) || tag.getOpenTag().getAttributes().containsKey(wicketId))
 			{
 				// Remove the last element from the component path
@@ -438,7 +438,7 @@
 	}
 
 	/**
 	 * Reset the markup to its defaults, except for the wicket namespace which
 	 * remains unchanged.
 	 */
 	final void reset()
@@ -142,7 +142,7 @@
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
@@ -166,7 +166,7 @@
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
@@ -199,9 +199,9 @@
 
 	/**
-	 * Get the wicket namespace valid for this specific markup
+	 * Get the org.apache.wicket namespace valid for this specific markup
 	 * 
@@ -404,7 +404,7 @@
 		else if (tag.isClose() && (this.currentPath != null))
 		{
-			// For example <wicket:message> does not have an id
+			// For example <org.apache.wicket:message> does not have an id
 			if ((tag.getOpenTag() == null) || tag.getOpenTag().getAttributes().containsKey(wicketId))
 			{
@@ -438,7 +438,7 @@
 
 	/**
-	 * Reset the markup to its defaults, except for the wicket namespace which
+	 * Reset the markup to its defaults, except for the org.apache.wicket namespace which
 	 * remains unchanged.
 	 */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupCache.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupCache.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupCache.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupCache.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupCache.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupCache.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupCache.java Tue Apr 10 11:15:14 2007
@@ -14,23 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.io.IOException;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.concurrent.ConcurrentHashMap;
+import org.apache.wicket.util.listener.IChangeListener;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.watch.ModificationWatcher;
+import org.apache.wicket.util.watch.Watcher;
 
-import wicket.Application;
-import wicket.MarkupContainer;
-import wicket.WicketRuntimeException;
-import wicket.util.concurrent.ConcurrentHashMap;
-import wicket.util.listener.IChangeListener;
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.watch.ModificationWatcher;
-import wicket.util.watch.Watcher;
 
 /**
  * Load markup and cache it for fast retrieval. If markup file changes, it'll be
@@ -121,7 +121,7 @@
 			throw new MarkupNotFoundException(
 					"Markup not found. Component class: "
 							+ container.getClass().getName()
-							+ " Enable debug messages for wicket.util.resource to get a list of all filenames tried");
+							+ " Enable debug messages for org.apache.wicket.util.resource to get a list of all filenames tried");
 		}
 
 		return null;
@@ -149,7 +149,7 @@
 
 	/**
 	 * The markup has just been loaded and now we check if markup inheritance
 	 * applies, which is if <wicket:extend> is found in the markup. If yes, than
 	 * load the base markups and merge the markup elements to create an updated
 	 * (merged) list of markup elements.
 	 * 
@@ -161,7 +161,7 @@
 	 */
 	private Markup checkForMarkupInheritance(final MarkupContainer container, final Markup markup)
 	{
 		// Check if markup contains <wicket:extend> which tells us that
 		// we need to read the inherited markup as well.
 		int extendIndex = requiresBaseMarkup(markup);
 		if (extendIndex == -1)
@@ -179,7 +179,7 @@
 			throw new MarkupNotFoundException(
 					"Parent markup of inherited markup not found. Component class: "
 							+ markup.getResource().getContainerInfo().getContainerClass().getName()
-							+ " Enable debug messages for wicket.util.resource.Resource to get a list of all filenames tried.");
+							+ " Enable debug messages for org.apache.wicket.util.resource.Resource to get a list of all filenames tried.");
 		}
 
 		final CharSequence key = markup.getResource().getCacheKey();
@@ -344,7 +344,7 @@
 			Markup markup = application.getMarkupSettings().getMarkupParserFactory()
 					.newMarkupParser().readAndParse(markupResourceStream);
 
 			// Check for markup inheritance. If it contains <wicket:extend>
 			// the two markups get merged.
 			markup = checkForMarkupInheritance(container, markup);
 
@@ -447,12 +447,12 @@
 	}
 
 	/**
 	 * Check if markup contains &lt;wicket:extend&gt; which tells us that we
 	 * need to read the inherited markup as well. &lt;wicket:extend&gt; MUST BE
 	 * the first wicket tag in the markup. Skip raw markup
 	 * 
 	 * @param markup
 	 * @return == 0, if no wicket:extend was found
 	 */
 	private int requiresBaseMarkup(final Markup markup)
 	{
@@ -149,7 +149,7 @@
 	/**
 	 * The markup has just been loaded and now we check if markup inheritance
-	 * applies, which is if <wicket:extend> is found in the markup. If yes, than
+	 * applies, which is if <org.apache.wicket:extend> is found in the markup. If yes, than
 	 * load the base markups and merge the markup elements to create an updated
 	 * (merged) list of markup elements.
@@ -161,7 +161,7 @@
 	private Markup checkForMarkupInheritance(final MarkupContainer container, final Markup markup)
 	{
-		// Check if markup contains <wicket:extend> which tells us that
+		// Check if markup contains <org.apache.wicket:extend> which tells us that
 		// we need to read the inherited markup as well.
 		int extendIndex = requiresBaseMarkup(markup);
@@ -344,7 +344,7 @@
 					.newMarkupParser().readAndParse(markupResourceStream);
 
-			// Check for markup inheritance. If it contains <wicket:extend>
+			// Check for markup inheritance. If it contains <org.apache.wicket:extend>
 			// the two markups get merged.
 			markup = checkForMarkupInheritance(container, markup);
@@ -447,12 +447,12 @@
 
 	/**
-	 * Check if markup contains &lt;wicket:extend&gt; which tells us that we
-	 * need to read the inherited markup as well. &lt;wicket:extend&gt; MUST BE
-	 * the first wicket tag in the markup. Skip raw markup
+	 * Check if markup contains &lt;org.apache.wicket:extend&gt; which tells us that we
+	 * need to read the inherited markup as well. &lt;org.apache.wicket:extend&gt; MUST BE
+	 * the first org.apache.wicket tag in the markup. Skip raw markup
 	 * 
 	 * @param markup
@@ -447,12 +447,12 @@
 	 * 
 	 * @param markup
-	 * @return == 0, if no wicket:extend was found
+	 * @return == 0, if no org.apache.wicket:extend was found
 	 */
 	private int requiresBaseMarkup(final Markup markup)